@@ -292,3 +292,17 @@ void PuntateMain::on_stream18_clicked()
     process.start("sh /opt/serviziopubblico/script/p18.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down19_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d19.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream19_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p19.sh");
+    process.waitForFinished();
+}
