@@ -92,6 +92,10 @@ private slots:
 
     void on_stream18_clicked();
 
+    void on_down19_clicked();
+
+    void on_stream19_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
